import { View, Text, TouchableOpacity, ViewStyle } from 'react-native';
import React, { useState } from 'react';
import CalendarIcon from '@/assets/icons/Calendar-fill.svg';
import styles from './styles';
import DateTimePickerModal from 'react-native-modal-datetime-picker';
import moment from 'moment';
import { StyleProp } from 'react-native';

interface PropsType {
  onSelectDate?: (date: any) => void;
  maximumDate?: Date;
  minimumDate?: Date;
  defaultDate?: string | undefined;
  style?: StyleProp<ViewStyle>;
  placeholder?: string;
  testID?: string;
  disabled?: boolean; // New prop to disable the date picker
}
const CustomDatePicker = (props: PropsType) => {
  const { onSelectDate, minimumDate, maximumDate, defaultDate, style, placeholder, disabled } =
    props;
  const [isDatePickerVisible, setDatePickerVisibility] = useState(false);
  const [selectDate, setSelectDate] = useState(undefined);

  const handleConfirm = (date: any) => {
    setDatePickerVisibility(false);
    onSelectDate && onSelectDate(date);
    setSelectDate(date);
  };

  const onPressIcon = () => {
    !disabled && setDatePickerVisibility(true);
  };

  return (
    <View style={[styles.container, style]}>
      <Text style={styles.text}>
        {selectDate != undefined ? moment(selectDate).format('MMM D YYYY') : placeholder}
      </Text>
      <TouchableOpacity onPress={onPressIcon} disabled={disabled}>
        <CalendarIcon />
      </TouchableOpacity>
      <DateTimePickerModal
        isVisible={isDatePickerVisible}
        mode='date'
        display='inline'
        date={selectDate}
        onConfirm={handleConfirm}
        onCancel={() => {
          setDatePickerVisibility(false);
        }}
        minimumDate={minimumDate}
        maximumDate={maximumDate}
        disabled={disabled}
      />
    </View>
  );
};

export default CustomDatePicker;
