/* eslint-disable @typescript-eslint/no-explicit-any */
import { View, Modal, NativeSyntheticEvent, Text, GestureResponderEvent } from 'react-native';
import React from 'react';

import AnimatedLottieView from 'lottie-react-native';
import { Constants } from '@/utils/constants';
import styles from './styles';
import PrimaryButton from '@/components/PrimaryButton';
import { useUpdateEffect } from '@/utils/useUpdateEffect';

const NoInternetDialog = (props: {
  visible?: boolean;
  onRequestClose?: (event: NativeSyntheticEvent<any>) => void;
  onPress?: ((event: GestureResponderEvent) => void) | undefined;
}) => {
  const { visible, onRequestClose, onPress } = props;
  const [loading, setLoading] = React.useState(false);

  const handlePress = (event: GestureResponderEvent) => {
    setLoading(true);
    onPress && onPress(event);
  };

  useUpdateEffect(() => {
    setTimeout(() => {
      setLoading(false);
    }, 2000);
  }, [loading]);

  return (
    <Modal
      visible={visible}
      statusBarTranslucent
      transparent={true}
      onRequestClose={onRequestClose}
      animationType='fade'
    >
      <View style={styles.root}>
        <View style={styles.card}>
          <AnimatedLottieView
            style={styles.animation}
            source={require('../../../assets/animation/NoInternet1.json')}
            autoPlay
            speed={0.9}
            loop={true}
          />
          <Text style={styles.title}>{Constants.No_Internet}</Text>
          <Text style={styles.discretion}>{Constants.No_Internet_Sub}</Text>
          <Text style={styles.discretion}>{Constants.No_Internet_Sub2}</Text>
          <PrimaryButton
            loading={loading}
            style={styles.button}
            title={Constants.Retry}
            onPress={handlePress}
          />
        </View>
      </View>
    </Modal>
  );
};

export default NoInternetDialog;
