import { View, Modal, NativeSyntheticEvent, Text } from 'react-native';
import React, { useEffect, useState } from 'react';

import { STATUS } from '@/features/services/status_constants';
import styles from './styles';
import AnimatedLottieView from 'lottie-react-native';
import { Constants } from '@/utils/constants';

const ServerDialog = (props: {
  visible?: boolean;
  status?: 'IDLE' | 'LOADING' | 'SUCCEEDED' | 'FAILED' | undefined;
  onRequestClose?: (event: NativeSyntheticEvent<any>) => void;
}) => {
  const { visible, onRequestClose, status } = props;

  const [loading, setLoading] = useState(false);

  // Time out for loading
  useEffect(() => {
    if (status == STATUS.LOADING) {
      setLoading(true);
    } else {
      setTimeout(() => {
        setLoading(false);
      }, 1000);
    }
  }, [status]);

  return (
    <Modal
      visible={visible ? visible : loading}
      statusBarTranslucent
      transparent={true}
      onRequestClose={onRequestClose}
      animationType='fade'
    >
      <View style={styles.root}>
        <View style={styles.card}>
          <AnimatedLottieView
            style={styles.animation}
            source={require('../../../assets/animation/Server1.json')}
            autoPlay
            speed={0.9}
            loop={true}
          />
          <Text style={styles.title}>{Constants.SPLASH_TITLE}</Text>
          <Text style={styles.discretion}>{Constants.SPLASH_SUBTITLE}</Text>
        </View>
      </View>
    </Modal>
  );
};

export default ServerDialog;
