import {
  View,
  TextInput,
  Image,
  ImageSourcePropType,
  TextInputFocusEventData,
  NativeSyntheticEvent,
} from 'react-native';
import React from 'react';

import DropdownComponent from '../DropDown';
import SecondaryDropDown from '@/assets/icons/SecondaryDropDown.svg';
import styles from './styles';

interface PropsTypes {
  source: ImageSourcePropType;
  dropdownData: any[];
  dropdownValue: string;
  dropdownOnChange: (item: { label: string; value: string }) => void;
  placeholder?: string;
  onChangeText?: ((text: string) => void) | undefined;
  value?: string;
  onBlur?: ((e: NativeSyntheticEvent<TextInputFocusEventData>) => void) | undefined;
  testID?: string | undefined;
}

const MoneyInput = (props: PropsTypes) => {
  const {
    source,
    dropdownData,
    dropdownOnChange,
    dropdownValue,
    placeholder,
    onChangeText,
    value,
    onBlur,
    testID,
  } = props;
  return (
    <View style={styles.root}>
      <TextInput
        testID={testID}
        placeholderTextColor={'#fff'}
        keyboardType='numeric'
        placeholder={placeholder}
        style={styles.textInput}
        onChangeText={onChangeText}
        value={value}
        onBlur={onBlur}
      />
      <View style={styles.divider} />
      <Image style={styles.flag} source={source} />

      <DropdownComponent
        testID={testID}
        customRightIcon={() => <SecondaryDropDown />}
        style={styles.dropdown}
        placeholderStyle={styles.dropdownText}
        placeholder=''
        selectedTextStyle={styles.dropdownText}
        data={dropdownData}
        value={dropdownValue}
        onChange={dropdownOnChange}
      />
    </View>
  );
};

export default MoneyInput;
