import {
  GestureResponderEvent,
  StyleProp,
  Text,
  TouchableOpacity,
  ViewProps,
  ViewStyle,
  ActivityIndicator,
} from 'react-native';
import React from 'react';
import { styles } from './styles';
import * as Animatable from 'react-native-animatable';

interface propTypes {
  onPress?: ((event: GestureResponderEvent) => void) | undefined;
  title: string;
  buttonRef?:
    | React.LegacyRef<
        React.ClassicComponent<Animatable.AnimatableProperties<ViewStyle> & ViewProps, any>
      >
    | undefined;
  style?: StyleProp<ViewStyle>;
  loading?: boolean;
  testID?: string | undefined;
}
const PrimaryButton = (props: propTypes) => {
  const { onPress, title, buttonRef, style, loading } = props;
  return (
    <Animatable.View ref={buttonRef} style={[styles.root, style]}>
      {loading ? (
        <ActivityIndicator size='large' color='white' style={styles.indicator} />
      ) : (
        <TouchableOpacity style={styles.submitButton} onPress={onPress}>
          <Text style={styles.submitButtonText}>{title}</Text>
        </TouchableOpacity>
      )}
    </Animatable.View>
  );
};

export default PrimaryButton;
