import React from 'react';
import {
  View,
  Text,
  TextInput,
  KeyboardTypeOptions,
  NativeSyntheticEvent,
  TextInputFocusEventData,
  StyleProp,
  ViewStyle,
} from 'react-native';

// import { TextInput } from 'react-native-paper';
import { widthPercentageToDP as wp } from 'react-native-responsive-screen';
import styles from './styles';
import { ColorSheet } from '@/utils/ColorSheet';

interface propTypes {
  placeholder?: string;
  value?: string;
  onFocus?: (e: NativeSyntheticEvent<TextInputFocusEventData>) => void;
  keyboardType?: KeyboardTypeOptions;
  onBlur?: (e: NativeSyntheticEvent<TextInputFocusEventData>) => void;
  onChangeText?: (text: string) => void;
  onChangeTextFunc?: (text: string) => void;
  secureTextEntry?: boolean;
  disable?: boolean | undefined;
  texterror?: string;
  style?: StyleProp<ViewStyle>;
  rightIcon?: React.ReactNode;
  onEndEditing?: (e: NativeSyntheticEvent<TextInputFocusEventData>) => void;
  testID?: string | undefined;
}

const SecondaryTextInput = (props: propTypes) => {
  const {
    placeholder,
    value,
    onFocus,
    onChangeText,
    onBlur,
    secureTextEntry,
    keyboardType,
    disable,
    texterror,
    style,
    rightIcon,
    onEndEditing,
    testID,
  } = props;

  const [isFocused, setIsFocused] = React.useState(false);
  const inputFocus = (e: NativeSyntheticEvent<TextInputFocusEventData>) => {
    onFocus && onFocus(e);
    setIsFocused(true);
  };
  const inputBlur = (e: NativeSyntheticEvent<TextInputFocusEventData>) => {
    onBlur && onBlur(e);
    setIsFocused(false);
  };

  return (
    <View style={[styles.root, style]}>
      <View
        style={[
          styles.container,
          {
            borderColor: isFocused ? ColorSheet.Text3 : ColorSheet.Grey,
            opacity: disable ? 0.3 : 1,
          },
        ]}
      >
        <TextInput
          placeholder={placeholder}
          placeholderTextColor={ColorSheet.White}
          value={value}
          onFocus={inputFocus}
          onBlur={inputBlur}
          onEndEditing={onEndEditing}
          editable={!disable}
          onChangeText={onChangeText}
          keyboardType={keyboardType}
          secureTextEntry={secureTextEntry}
          style={styles.txtstyle}
          testID={testID}
        />
        {props.rightIcon && rightIcon}
      </View>

      {texterror ? <Text style={{ color: 'red', marginLeft: wp(3) }}>{texterror}</Text> : null}
    </View>
  );
};

export default SecondaryTextInput;
