import React from 'react';
import {
  View,
  Text,
  TextInput,
  KeyboardTypeOptions,
  NativeSyntheticEvent,
  TextInputFocusEventData,
  StyleProp,
  ViewStyle,
  TextInputEndEditingEventData,
  TextStyle,
} from 'react-native';

// import { TextInput } from 'react-native-paper';
import { widthPercentageToDP as wp } from 'react-native-responsive-screen';
import styles from './styles';
import { ColorSheet } from '@/utils/ColorSheet';

interface propTypes {
  placeholder?: string;
  value?: string;
  onFocus?: (e: NativeSyntheticEvent<TextInputFocusEventData>) => void;
  keyboardType?: KeyboardTypeOptions;
  onBlur?: (e: NativeSyntheticEvent<TextInputFocusEventData>) => void;
  onChangeText?: (text: string) => void;
  onChangeTextFunc?: (text: string) => void;
  secureTextEntry?: boolean;
  editable?: boolean | true;
  texterror?: string;
  testID?: string | undefined;
  style?: StyleProp<ViewStyle>;
  autoCapitalize?: 'none' | 'sentences' | 'words' | 'characters' | undefined;
  onEndEditing?: ((e: NativeSyntheticEvent<TextInputEndEditingEventData>) => void) | undefined;
  textInputStyle?: StyleProp<ViewStyle>;
  texterrorStyle?: StyleProp<TextStyle>;
}

const TextInputField = (props: propTypes) => {
  const {
    placeholder,
    value,
    onFocus,
    onChangeText,
    onBlur,
    secureTextEntry,
    keyboardType,
    editable,
    texterror,
    style,
    autoCapitalize,
    textInputStyle,
    onEndEditing,
    testID,
    texterrorStyle,
  } = props;

  const [isFocused, setIsFocused] = React.useState(false);
  const inputFocus = (e: NativeSyntheticEvent<TextInputFocusEventData>) => {
    onFocus && onFocus(e);
    setIsFocused(true);
  };
  const inputBlur = (e: NativeSyntheticEvent<TextInputFocusEventData>) => {
    onBlur && onBlur(e);
    setIsFocused(false);
  };

  return (
    <View style={style}>
      <TextInput
        testID={testID}
        placeholder={placeholder}
        placeholderTextColor={ColorSheet.White}
        value={value}
        onFocus={inputFocus}
        onBlur={inputBlur}
        onEndEditing={onEndEditing}
        editable={editable}
        onChangeText={onChangeText}
        keyboardType={keyboardType}
        secureTextEntry={secureTextEntry}
        style={[
          isFocused ? styles.focusedTextInput : styles.txtstyle,
          textInputStyle,
          editable === false && {
            color: ColorSheet.Grey,
          },
        ]}
        autoCapitalize={autoCapitalize}
      />
      {texterror ? (
        <Text style={[{ color: 'red', marginLeft: wp(3) }, texterrorStyle]}>{texterror}</Text>
      ) : null}
    </View>
  );
};

export default TextInputField;
