import { View, Text, TouchableOpacity, StyleSheet } from 'react-native';
import React from 'react';
import ICLine from '../../assets/icons/ICLine.svg';
import {
  widthPercentageToDP as wp,
  heightPercentageToDP as hp,
} from 'react-native-responsive-screen';
import { RFValue } from 'react-native-responsive-fontsize';
import RT1 from '../../assets/icons/RT1.svg';
import RT2 from '../../assets/icons/RT2.svg';
import RT3 from '../../assets/icons/RT3.svg';
import moment from 'moment';

interface PropsTypes {
  iconType: string | number;
  beneficiaryName: string;
  transactionDate: string;
  transactionStatus: string;
  amountReceived: string;
  // Add the testID prop to the interface
  testID: string;
  key?: React.Key | null | undefined;
}
const TransferCard = (props: PropsTypes) => {
  const {
    iconType,
    beneficiaryName,
    transactionDate,
    transactionStatus,
    amountReceived,
    testID,
    key,
  } = props;
  return (
    <TouchableOpacity key={key} testID={testID} style={styles.root}>
      <View style={styles.container}>
        <View style={{ flexDirection: 'row' }}>
          {/* <Image
            source={{
              uri: 'https://www.pngfind.com/pngs/m/16-162350_png-file-wallet-icon-png-free-transparent-png.png',
            }}
            style={{ height: 40, width: 40 }}
          /> */}

          <View
            style={{
              alignSelf: 'center',
            }}
          >
            {iconType == 3 ? <RT3 /> : iconType == 2 ? <RT2 /> : <RT1 />}
          </View>

          <View
            style={{
              marginLeft: wp(6),
              width: wp(55),
            }}
          >
            <Text
              style={{
                color: '#fff',
                fontSize: RFValue(12),
              }}
            >
              {beneficiaryName}
            </Text>
            <View style={{ flexDirection: 'row', marginTop: hp(0.4) }}>
              <Text style={{ color: '#0AD036', fontSize: RFValue(10) }}>{transactionStatus} </Text>
              <Text style={{ color: '#828282', fontSize: RFValue(10) }}>
                | {moment(transactionDate).format('DD.MM.YYYY')}
              </Text>
            </View>
          </View>
        </View>

        <Text
          style={{
            color: '#fff',
            fontSize: RFValue(12),
            textAlign: 'right',
            marginTop: hp(0.4),
          }}
        >
          {parseFloat(amountReceived).toFixed(2)} GBP
        </Text>
      </View>
      <ICLine />
    </TouchableOpacity>
  );
};

const styles = StyleSheet.create({
  root: {
    alignItems: 'center',
  },
  container: {
    flexDirection: 'row',
    justifyContent: 'space-around',
    width: wp(86),
    marginTop: hp(2),
    marginBottom: hp(2),
  },
});

export default TransferCard;
