import { View, Text, TouchableOpacity, Image, ImageSourcePropType } from 'react-native';
import React, { useState } from 'react';
import styles from './styles';
import Line from '@/assets/icons/ICLine.svg';
import {
  widthPercentageToDP as wp,
} from 'react-native-responsive-screen';

interface propTypes {
  onPress?: () => void;
  onPressView?: () => void;
  accountName: string;
  accountId: string;
  imageSource: ImageSourcePropType;
  lineVisible?: boolean;
  testID?: string | undefined;
  currencyImageurl: string;
}

const UserCard = (props: propTypes) => {
  const {
    onPress,
    onPressView,
    accountName,
    accountId,
    imageSource,
    lineVisible,
    testID,
    currencyImageurl,
  } = props;
  const [tapIcon, setTapIcon] = useState(true);

  return (
    <View style={styles.rootContainer}>
      <TouchableOpacity testID={testID} onPress={onPressView} style={styles.mainContainer}>
        <Image
          source={{
            uri: currencyImageurl,
          }}
          style={styles.flag}
        />
        <View style={styles.subContainer}>
          <Text style={styles.accountName}>{accountName}</Text>
          <Text style={styles.accountDetails}>{accountId}</Text>
        </View>
      </TouchableOpacity>
      <TouchableOpacity
        style={styles.iconButton}
        onPress={() => {
          setTapIcon(!tapIcon);
          onPress?.();
        }}
      >
        <Text style={styles.send}>Send</Text>
      </TouchableOpacity>
      {lineVisible && <Line width={wp(68)} style={styles.line} />}
    </View>
  );
};

export default UserCard;
